@@ -35,7 +35,7 @@ class FAAPI:
         self.cookies: List[Dict[str, Any]] = [] if cookies is None else cookies
         self.session: CloudflareScraper = make_session(self.cookies)
         self.robots: Dict[str, List[str]] = get_robots()
-        self.crawl_delay: float = float(self.robots["Crawl-delay"][0]) if self.robots.get("Crawl-delay", 0) else 1.0
+        self.crawl_delay: float = float(self.robots.get("Crawl-delay", [1.0])[0])
         self.last_get: float = perf_counter() - self.crawl_delay
         self.raise_for_delay: bool = False
 
@@ -71,28 +71,20 @@ class FAAPI:
         res = self.get(path, **params)
         return parse_page(res.text) if res.ok else None
 
-    def get_sub(self, sub_id: int, get_file: bool = False) -> Tuple[Submission, Optional[bytes]]:
-        assert isinstance(sub_id, int) and sub_id > 0
-
-        sub_page = self.get_parse(join_url("view", sub_id))
-        sub = Submission(sub_page)
-        sub_file = self.get_sub_file(sub) if get_file else None
+    def get_submission(self, submission_id: int, get_file: bool = False) -> Tuple[Submission, Optional[bytes]]:
+        sub = Submission(self.get_parse(join_url("view", int(submission_id))))
+        sub_file = self.get_submission_file(sub) if get_file else None
 
         return sub, sub_file
 
-    def get_sub_file(self, sub: Submission) -> Optional[bytes]:
+    def get_submission_file(self, submission: Submission) -> Optional[bytes]:
         self.handle_delay()
-        return get_binary_raw(self.session, sub.file_url)
+        return get_binary_raw(self.session, submission.file_url)
 
     def get_journal(self, journal_id: int) -> Journal:
-        assert isinstance(journal_id, int) and journal_id > 0
-
-        journal_page = self.get_parse(join_url("journal", journal_id))
-        return Journal(journal_page=journal_page)
+        return Journal(self.get_parse(join_url("journal", int(journal_id))))
 
     def userpage(self, user: str) -> Tuple[str, str, Optional[BeautifulSoup]]:
-        assert isinstance(user, str)
-
         page_parsed: Optional[BeautifulSoup] = self.get_parse(join_url("user", user))
 
         if check_page(page_parsed) != 0:
@@ -109,10 +101,7 @@ class FAAPI:
         return username, status, parse_page(description)
 
     def gallery(self, user: str, page: int = 1) -> Tuple[List[SubmissionPartial], int]:
-        assert isinstance(user, str)
-        assert isinstance(page, int) and page >= 1
-
-        page_parsed = self.get_parse(join_url("gallery", user, page))
+        page_parsed = self.get_parse(join_url("gallery", user, int(page)))
 
         if check_page(page_parsed) != 0:
             return [], 0
@@ -122,10 +111,7 @@ class FAAPI:
         return list(map(SubmissionPartial, subs)), (page + 1) if subs else 0
 
     def scraps(self, user: str, page: int = 1) -> Tuple[List[SubmissionPartial], int]:
-        assert isinstance(user, str)
-        assert isinstance(page, int) and page >= 1
-
-        page_parsed = self.get_parse(join_url("scraps", user, page))
+        page_parsed = self.get_parse(join_url("scraps", user, int(page)))
 
         if check_page(page_parsed) != 0:
             return [], 0
@@ -135,9 +121,6 @@ class FAAPI:
         return list(map(SubmissionPartial, subs)), (page + 1) if subs else 0
 
     def favorites(self, user: str, page: str = "") -> Tuple[List[SubmissionPartial], str]:
-        assert isinstance(user, str)
-        assert isinstance(page, str)
-
         page_parsed = self.get_parse(join_url("favorites", user, page))
 
         if check_page(page_parsed) != 0:
@@ -151,10 +134,7 @@ class FAAPI:
         return list(map(SubmissionPartial, subs)), page_next
 
     def journals(self, user: str, page: int = 1) -> Tuple[List[Journal], int]:
-        assert isinstance(user, str)
-        assert isinstance(page, int)
-
-        page_parsed = self.get_parse(join_url("journals", user, page))
+        page_parsed = self.get_parse(join_url("journals", user, int(page)))
 
         if check_page(page_parsed) != 0:
             return [], 0
@@ -169,9 +149,6 @@ class FAAPI:
         return journals, (page + 1) if journals else 0
 
     def search(self, q: str, page: int = 1, **params) -> Tuple[List[SubmissionPartial], int, int, int, int]:
-        assert isinstance(q, str)
-        assert isinstance(page, int)
-
         page_parsed = self.get_parse("search", q=q, page=page, **params)
 
         if check_page(page_parsed) != 0:
@@ -197,8 +174,6 @@ class FAAPI:
         4 request error
         """
 
-        assert isinstance(user, str)
-
         res = self.get(join_url("user", user))
 
         if not res.ok:
@@ -212,7 +187,7 @@ class FAAPI:
         else:
             return 3
 
-    def sub_exists(self, sub_id: int) -> int:
+    def submission_exists(self, submission_id: int) -> int:
         """
         0 okay
         1 account disabled
@@ -221,9 +196,7 @@ class FAAPI:
         4 request error
         """
 
-        assert isinstance(sub_id, int) and sub_id > 0
-
-        res = self.get(join_url("view", sub_id))
+        res = self.get(join_url("view", submission_id))
 
         if not res.ok:
             return 4
@@ -245,8 +218,6 @@ class FAAPI:
         4 request error
         """
 
-        assert isinstance(journal_id, int) and journal_id > 0
-
         res = self.get(join_url("journal", journal_id))
 
         if not res.ok:
